aboutsummaryrefslogtreecommitdiff
path: root/src/jtag/interfaces.h
diff options
context:
space:
mode:
authorAntonio Borneo <borneo.antonio@gmail.com>2019-01-22 16:31:18 +0100
committerTomas Vanek <vanekt@fbl.cz>2020-01-14 11:39:37 +0000
commitefd1d642220a4f6d3b9a9607c186452b265400d2 (patch)
tree13272d92e149e66524d420111fe740868a7e30ce /src/jtag/interfaces.h
parent7268ff22c399832ee09ca3216753f17473ae9fab (diff)
downloadriscv-openocd-efd1d642220a4f6d3b9a9607c186452b265400d2.zip
riscv-openocd-efd1d642220a4f6d3b9a9607c186452b265400d2.tar.gz
riscv-openocd-efd1d642220a4f6d3b9a9607c186452b265400d2.tar.bz2
adapter: switch from struct jtag_interface to adapter_driver
To reorganize the adapters code, introduce an adapter_driver struct that contains all the adapter generic part, while keeping in two separate struct the specific API jtag_ops and swd_ops. Move the allocation of *adapter_driver from the JTAG-specific file core.c to the more adapter-specific file adapter.c While splitting the old jtag_interface for every driver, put the fields in the same order as in the struct declaration so we keep a consistent code across all the drivers. While other transport specific API could/would be added as separate ops, nothing is done here for HLA. Change-Id: I2d60f97ac514c0dd2d93a6ec9be66fd9d388dad5 Signed-off-by: Antonio Borneo <borneo.antonio@gmail.com> Reviewed-on: http://openocd.zylin.com/4900 Tested-by: jenkins Reviewed-by: Tomas Vanek <vanekt@fbl.cz>
Diffstat (limited to 'src/jtag/interfaces.h')
-rw-r--r--src/jtag/interfaces.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/jtag/interfaces.h b/src/jtag/interfaces.h
index 02d201b..f85865a 100644
--- a/src/jtag/interfaces.h
+++ b/src/jtag/interfaces.h
@@ -36,9 +36,9 @@
#include <jtag/interface.h>
-/** Dynamically load all JTAG interface modules from specified directory. */
-void jtag_interface_modules_load(const char *path);
+/** Dynamically load all adapter driver modules from specified directory. */
+void adapter_driver_modules_load(const char *path);
-extern struct jtag_interface *jtag_interfaces[];
+extern struct adapter_driver *adapter_drivers[];
#endif /* OPENOCD_JTAG_INTERFACES_H */